v0.2.6

11/12/2020

ENH - Add  GE SCAN processing with deltam or cbf

ENH - supressed freesurfer processing, FSL FLIRT with BBR for registration

ENH - basil and scorescrub as options, cbf computation is only default


